@@ -236,7 +236,7 @@ class WeatherFlowApiClient:
                 dew_point=self.cnv.temperature(obervations.get("dew_point")),
                 wet_bulb_temperature=self.cnv.temperature(obervations.get("wet_bulb_temperature")),
                 delta_t=obervations.get("delta_t"),
-                air_density=obervations.get("air_density"),
+                air_density=self.cnv.density(obervations.get("air_density")),
                 pressure_trend=obervations.get("pressure_trend"),
                 is_raining=self.calc.is_raining(obervations.get("precip")),
                 is_freezing=self.calc.is_freezing(obervations.get("air_temperature")),
@@ -305,20 +305,21 @@ class WeatherFlowApiClient:
 
             for item in forecast_daily:
                 calc_values = self.calc.day_forecast_extras(item, data["forecast"]["hourly"])
-                day_item = ForecastDailyDescription(
-                    utc_time=self.cnv.utc_from_timestamp(item["day_start_local"]),
-                    conditions=item["conditions"],
-                    icon=item["icon"],
-                    sunrise=item["sunrise"],
-                    sunset=item["sunset"],
-                    air_temp_high=self.cnv.temperature(item["air_temp_high"]),
-                    air_temp_low=self.cnv.temperature(item["air_temp_low"]),
-                    precip=self.cnv.rain(calc_values["precip"]),
-                    precip_probability=item["precip_probability"],
-                    wind_avg=self.cnv.windspeed(calc_values["wind_avg"], self.homeassistant),
-                    wind_direction=calc_values["wind_direction"],
-                )
-                entity_data.forecast_daily.append(day_item)
+                if calc_values is not None:
+                    day_item = ForecastDailyDescription(
+                        utc_time=self.cnv.utc_from_timestamp(item["day_start_local"]),
+                        conditions=item["conditions"],
+                        icon=item["icon"],
+                        sunrise=item["sunrise"],
+                        sunset=item["sunset"],
+                        air_temp_high=self.cnv.temperature(item["air_temp_high"]),
+                        air_temp_low=self.cnv.temperature(item["air_temp_low"]),
+                        precip=self.cnv.rain(calc_values["precip"]),
+                        precip_probability=item["precip_probability"],
+                        wind_avg=self.cnv.windspeed(calc_values["wind_avg"], self.homeassistant),
+                        wind_direction=calc_values["wind_direction"],
+                    )
+                    entity_data.forecast_daily.append(day_item)
 
             forecast_hourly = data["forecast"]["hourly"]
             for item in forecast_hourly:
@@ -348,10 +349,11 @@ class WeatherFlowApiClient:
         """Return unit of meassurement based on unit system."""
         density_unit = "kg/m^3" if self._is_metric else "lb/ft^3"
         distance_unit = "km" if self._is_metric else "mi"
-        length_unit = "m/s" if self._is_metric else "mi/h"
-        length_km_unit = "km/h" if self._is_metric else "mi/h"
+        length_unit = "m/s" if self._is_metric else "mph"
+        length_km_unit = "km/h" if self._is_metric else "mph"
         pressure_unit = "hPa" if self._is_metric else "inHg"
         precip_unit = "mm" if self._is_metric else "in"
+        temp_unit = "°C" if self._is_metric else "°F"
 
         units_list: dict = {
             "none": None,
@@ -362,6 +364,7 @@ class WeatherFlowApiClient:
             "pressure": pressure_unit,
             "precipitation": precip_unit,
             "precipitation_rate": f"{precip_unit}/h",
+            "temperature": temp_unit,
         }
 
         return units_list
