@@ -1,13 +1,14 @@
+"""Exception handling for WeatherFlow Rest."""
 class WeatherFlowError(Exception):
-    """Base class for all other WeatherFlow errors"""
+    """Base class for all other WeatherFlow errors."""
 
 
 class ClientError(WeatherFlowError):
-    """Base Class for all other Unifi Protect client errors"""
+    """Base Class for all other Unifi Protect client errors."""
 
 
 class BadRequest(ClientError):
-    """Invalid request from API Client"""
+    """Invalid request from API Client."""
 
 
 class Invalid(ClientError):
