@@ -30,7 +30,7 @@ class Conversions:
         """Return inHg from mb/hPa."""
         if value is None or self.units == UNIT_TYPE_METRIC:
             return value
-        return round(value * 0.029530, 1)
+        return round(value * 0.029530, 3)
 
     def rain(self, value) -> float:
         """Convert rain units."""
@@ -98,6 +98,8 @@ class Conversions:
 
     def utc_from_timestamp(self, timestamp: int) -> dt.datetime:
         """Return a UTC time from a timestamp."""
+        if timestamp is None:
+            return None
         return dt.datetime.utcfromtimestamp(timestamp).replace(tzinfo=UTC)
 
 
@@ -139,7 +141,11 @@ class Calculations:
         _sum_wind_avg = sum(_wind_avg) / len(_wind_avg)
         _sum_wind_bearing = sum(_wind_bearing) / len(_wind_bearing)
 
-        return {"precip": round(_precip, 1), "wind_avg": round(_sum_wind_avg, 1), "wind_direction": int(_sum_wind_bearing)}
+        return {
+            "precip": round(_precip, 1),
+            "wind_avg": round(_sum_wind_avg, 1),
+            "wind_direction": int(_sum_wind_bearing)
+        }
 
     def visibility(self, elevation, air_temperature, relative_humidity, dewpoint) -> float:
         """Return the calculated visibility."""
@@ -241,6 +247,9 @@ class Calculations:
 
     def beaufort_value(self, wind_speed: float) -> BeaufortDescription:
         """Return Beaufort Value and Description."""
+        if wind_speed is None:
+            return BeaufortDescription(value=0, description="None")
+
         mapping_text = {
             "32.7": [12, "hurricane"],
             "28.5": [11, "violent_storm"],
